@@ -1,12 +1,12 @@
 #!/usr/bin/perl -w
-# sample
-#$Id: sample_Pod-Html-HtmlTree.pl 27 2005-03-12 15:34:24Z root $
 use strict;
+use FindBin;
+use lib "$FindBin::Bin/../lib/";
 use Data::Dumper;
 use Pod::Html::HtmlTree;
 
 my $p =  Pod::Html::HtmlTree->new;
- $p->indir ( '/usr/lib/perl5/site_perl/5.8.3/Pod'     );
+ $p->indir ( '/usr/lib/perl5/5.8.5'     );
  $p->outdir( '/tmp/pod' );
  $p->args({
     css =>'http://localhost/pod.css',
